@@ -569,7 +569,14 @@ fn get_input_or_die() -> Result<String, i32> {
     let mut input = String::new();
     match io::stdin().read_line(&mut input) {
         Ok(_num_bytes) => {
-            Ok(input.trim().to_string())
+
+            /* EOF Return error of 0 to indicate time for a clean exit.  */
+            if _num_bytes == 0 {
+                Err(0)
+            }
+            else {
+                Ok(input.trim().to_string())
+            }
         }
         Err(_) => {
             println!("Unable to read input");
@@ -945,6 +952,8 @@ struct State {
     unsaved_changes: bool,
     filename: String,
 
+    show_prompt: bool,
+
     /* Current byte number, 0 to len -1 */
     index: usize,
 
@@ -1033,7 +1042,7 @@ fn pluses(state:&mut State, num_pluses:usize) -> Result<usize, String> {
 }
 
 
-pub fn actual_runtime(filename: &str) -> i32 {
+pub fn actual_runtime(filename:&str, quiet:bool) -> i32 {
     let file = match File::open(filename) {
         Ok(filehandle) => {
             Some(filehandle)
@@ -1082,6 +1091,7 @@ pub fn actual_runtime(filename: &str) -> i32 {
         radix: 16,
         filename: filename.to_owned(),
         show_byte_numbers: true,
+        show_prompt: !quiet,
         show_chars: true,
         unsaved_changes: false,
         index: 0,
@@ -1091,14 +1101,18 @@ pub fn actual_runtime(filename: &str) -> i32 {
         n_padding: "      ".to_owned(),
     };
 
-    println!("{} bytes\n? for help\n",
-            hex_unless_dec(state.all_bytes.len(), state.radix));
-    print_state(&state);
-    println!();
-    print_bytes(&state, state.range());
+    if !quiet {
+        println!("{} bytes\n? for help\n",
+                hex_unless_dec(state.all_bytes.len(), state.radix));
+        print_state(&state);
+        println!();
+        print_bytes(&state, state.range());
+    }
 
     loop {
-        print!("*");
+        if state.show_prompt {
+            print!("*");
+        }
         io::stdout().flush().unwrap();
         let input = match get_input_or_die() {
             Ok(input) => input,
